# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.query_api import QueryApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestQueryApi(unittest.TestCase):
    """QueryApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.query_api.QueryApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_query_api(self):
        """Test case for query_api

        Perform a charting query against Wavefront servers that returns the appropriate points in the specified time window and granularity  # noqa: E501
        """
        pass

    def test_query_raw(self):
        """Test case for query_raw

        Perform a raw data query against Wavefront servers that returns second granularity points grouped by tags  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class CustomerFacingUserObject(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'customer': 'str',
        'escaped_identifier': 'str',
        'gravatar_url': 'str',
        'groups': 'list[str]',
        'id': 'str',
        'identifier': 'str',
        'ingestion_policy_id': 'str',
        'last_successful_login': 'int',
        '_self': 'bool',
        'united_permissions': 'list[str]',
        'united_roles': 'list[str]',
        'user_groups': 'list[str]'
    }

    attribute_map = {
        'customer': 'customer',
        'escaped_identifier': 'escapedIdentifier',
        'gravatar_url': 'gravatarUrl',
        'groups': 'groups',
        'id': 'id',
        'identifier': 'identifier',
        'ingestion_policy_id': 'ingestionPolicyId',
        'last_successful_login': 'lastSuccessfulLogin',
        '_self': 'self',
        'united_permissions': 'unitedPermissions',
        'united_roles': 'unitedRoles',
        'user_groups': 'userGroups'
    }

    def __init__(self, customer=None, escaped_identifier=None, gravatar_url=None, groups=None, id=None, identifier=None, ingestion_policy_id=None, last_successful_login=None, _self=None, united_permissions=None, united_roles=None, user_groups=None, _configuration=None):  # noqa: E501
        """CustomerFacingUserObject - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._customer = None
        self._escaped_identifier = None
        self._gravatar_url = None
        self._groups = None
        self._id = None
        self._identifier = None
        self._ingestion_policy_id = None
        self._last_successful_login = None
        self.__self = None
        self._united_permissions = None
        self._united_roles = None
        self._user_groups = None
        self.discriminator = None

        self.customer = customer
        if escaped_identifier is not None:
            self.escaped_identifier = escaped_identifier
        if gravatar_url is not None:
            self.gravatar_url = gravatar_url
        if groups is not None:
            self.groups = groups
        self.id = id
        self.identifier = identifier
        if ingestion_policy_id is not None:
            self.ingestion_policy_id = ingestion_policy_id
        if last_successful_login is not None:
            self.last_successful_login = last_successful_login
        self._self = _self
        if united_permissions is not None:
            self.united_permissions = united_permissions
        if united_roles is not None:
            self.united_roles = united_roles
        if user_groups is not None:
            self.user_groups = user_groups

    @property
    def customer(self):
        """Gets the customer of this CustomerFacingUserObject.  # noqa: E501

        The id of the customer to which the user belongs  # noqa: E501

        :return: The customer of this CustomerFacingUserObject.  # noqa: E501
        :rtype: str
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this CustomerFacingUserObject.

        The id of the customer to which the user belongs  # noqa: E501

        :param customer: The customer of this CustomerFacingUserObject.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and customer is None:
            raise ValueError("Invalid value for `customer`, must not be `None`")  # noqa: E501

        self._customer = customer

    @property
    def escaped_identifier(self):
        """Gets the escaped_identifier of this CustomerFacingUserObject.  # noqa: E501

        URL Escaped Identifier  # noqa: E501

        :return: The escaped_identifier of this CustomerFacingUserObject.  # noqa: E501
        :rtype: str
        """
        return self._escaped_identifier

    @escaped_identifier.setter
    def escaped_identifier(self, escaped_identifier):
        """Sets the escaped_identifier of this CustomerFacingUserObject.

        URL Escaped Identifier  # noqa: E501

        :param escaped_identifier: The escaped_identifier of this CustomerFacingUserObject.  # noqa: E501
        :type: str
        """

        self._escaped_identifier = escaped_identifier

    @property
    def gravatar_url(self):
        """Gets the gravatar_url of this CustomerFacingUserObject.  # noqa: E501

        URL id For User's gravatar (see gravatar.com), if one exists.  # noqa: E501

        :return: The gravatar_url of this CustomerFacingUserObject.  # noqa: E501
        :rtype: str
        """
        return self._gravatar_url

    @gravatar_url.setter
    def gravatar_url(self, gravatar_url):
        """Sets the gravatar_url of this CustomerFacingUserObject.

        URL id For User's gravatar (see gravatar.com), if one exists.  # noqa: E501

        :param gravatar_url: The gravatar_url of this CustomerFacingUserObject.  # noqa: E501
        :type: str
        """

        self._gravatar_url = gravatar_url

    @property
    def groups(self):
        """Gets the groups of this CustomerFacingUserObject.  # noqa: E501

        List of permission groups this user has been granted access to  # noqa: E501

        :return: The groups of this CustomerFacingUserObject.  # noqa: E501
        :rtype: list[str]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """Sets the groups of this CustomerFacingUserObject.

        List of permission groups this user has been granted access to  # noqa: E501

        :param groups: The groups of this CustomerFacingUserObject.  # noqa: E501
        :type: list[str]
        """

        self._groups = groups

    @property
    def id(self):
        """Gets the id of this CustomerFacingUserObject.  # noqa: E501

        The unique identifier of this user, which should be their valid email address  # noqa: E501

        :return: The id of this CustomerFacingUserObject.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CustomerFacingUserObject.

        The unique identifier of this user, which should be their valid email address  # noqa: E501

        :param id: The id of this CustomerFacingUserObject.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def identifier(self):
        """Gets the identifier of this CustomerFacingUserObject.  # noqa: E501

        The unique identifier of this user, which should be their valid email address  # noqa: E501

        :return: The identifier of this CustomerFacingUserObject.  # noqa: E501
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this CustomerFacingUserObject.

        The unique identifier of this user, which should be their valid email address  # noqa: E501

        :param identifier: The identifier of this CustomerFacingUserObject.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and identifier is None:
            raise ValueError("Invalid value for `identifier`, must not be `None`")  # noqa: E501

        self._identifier = identifier

    @property
    def ingestion_policy_id(self):
        """Gets the ingestion_policy_id of this CustomerFacingUserObject.  # noqa: E501

        The identifier of the ingestion policy linked with user.  # noqa: E501

        :return: The ingestion_policy_id of this CustomerFacingUserObject.  # noqa: E501
        :rtype: str
        """
        return self._ingestion_policy_id

    @ingestion_policy_id.setter
    def ingestion_policy_id(self, ingestion_policy_id):
        """Sets the ingestion_policy_id of this CustomerFacingUserObject.

        The identifier of the ingestion policy linked with user.  # noqa: E501

        :param ingestion_policy_id: The ingestion_policy_id of this CustomerFacingUserObject.  # noqa: E501
        :type: str
        """

        self._ingestion_policy_id = ingestion_policy_id

    @property
    def last_successful_login(self):
        """Gets the last_successful_login of this CustomerFacingUserObject.  # noqa: E501

        The last time the user logged in, in epoch milliseconds  # noqa: E501

        :return: The last_successful_login of this CustomerFacingUserObject.  # noqa: E501
        :rtype: int
        """
        return self._last_successful_login

    @last_successful_login.setter
    def last_successful_login(self, last_successful_login):
        """Sets the last_successful_login of this CustomerFacingUserObject.

        The last time the user logged in, in epoch milliseconds  # noqa: E501

        :param last_successful_login: The last_successful_login of this CustomerFacingUserObject.  # noqa: E501
        :type: int
        """

        self._last_successful_login = last_successful_login

    @property
    def _self(self):
        """Gets the _self of this CustomerFacingUserObject.  # noqa: E501

        Whether this user is the one calling the API  # noqa: E501

        :return: The _self of this CustomerFacingUserObject.  # noqa: E501
        :rtype: bool
        """
        return self.__self

    @_self.setter
    def _self(self, _self):
        """Sets the _self of this CustomerFacingUserObject.

        Whether this user is the one calling the API  # noqa: E501

        :param _self: The _self of this CustomerFacingUserObject.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and _self is None:
            raise ValueError("Invalid value for `_self`, must not be `None`")  # noqa: E501

        self.__self = _self

    @property
    def united_permissions(self):
        """Gets the united_permissions of this CustomerFacingUserObject.  # noqa: E501

        The list of account's permissions assigned directly or through united roles assigned to it  # noqa: E501

        :return: The united_permissions of this CustomerFacingUserObject.  # noqa: E501
        :rtype: list[str]
        """
        return self._united_permissions

    @united_permissions.setter
    def united_permissions(self, united_permissions):
        """Sets the united_permissions of this CustomerFacingUserObject.

        The list of account's permissions assigned directly or through united roles assigned to it  # noqa: E501

        :param united_permissions: The united_permissions of this CustomerFacingUserObject.  # noqa: E501
        :type: list[str]
        """

        self._united_permissions = united_permissions

    @property
    def united_roles(self):
        """Gets the united_roles of this CustomerFacingUserObject.  # noqa: E501

        The list of account's roles assigned directly or through user groups assigned to it  # noqa: E501

        :return: The united_roles of this CustomerFacingUserObject.  # noqa: E501
        :rtype: list[str]
        """
        return self._united_roles

    @united_roles.setter
    def united_roles(self, united_roles):
        """Sets the united_roles of this CustomerFacingUserObject.

        The list of account's roles assigned directly or through user groups assigned to it  # noqa: E501

        :param united_roles: The united_roles of this CustomerFacingUserObject.  # noqa: E501
        :type: list[str]
        """

        self._united_roles = united_roles

    @property
    def user_groups(self):
        """Gets the user_groups of this CustomerFacingUserObject.  # noqa: E501

        List of user group identifiers this user belongs to  # noqa: E501

        :return: The user_groups of this CustomerFacingUserObject.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_groups

    @user_groups.setter
    def user_groups(self, user_groups):
        """Sets the user_groups of this CustomerFacingUserObject.

        List of user group identifiers this user belongs to  # noqa: E501

        :param user_groups: The user_groups of this CustomerFacingUserObject.  # noqa: E501
        :type: list[str]
        """

        self._user_groups = user_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustomerFacingUserObject, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomerFacingUserObject):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CustomerFacingUserObject):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wavefront_api_client.api_client import ApiClient


class MetricsPolicyApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_metrics_policy(self, **kwargs):  # noqa: E501
        """Get the metrics policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_metrics_policy(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ResponseContainerMetricsPolicyReadModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_metrics_policy_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_metrics_policy_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_metrics_policy_with_http_info(self, **kwargs):  # noqa: E501
        """Get the metrics policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_metrics_policy_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ResponseContainerMetricsPolicyReadModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_metrics_policy" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/metricspolicy', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerMetricsPolicyReadModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_metrics_policy_by_version(self, version, **kwargs):  # noqa: E501
        """Get a specific historical version of a metrics policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_metrics_policy_by_version(version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int version: (required)
        :return: ResponseContainerMetricsPolicyReadModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_metrics_policy_by_version_with_http_info(version, **kwargs)  # noqa: E501
        else:
            (data) = self.get_metrics_policy_by_version_with_http_info(version, **kwargs)  # noqa: E501
            return data

    def get_metrics_policy_by_version_with_http_info(self, version, **kwargs):  # noqa: E501
        """Get a specific historical version of a metrics policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_metrics_policy_by_version_with_http_info(version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int version: (required)
        :return: ResponseContainerMetricsPolicyReadModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_metrics_policy_by_version" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version' is set
        if self.api_client.client_side_validation and ('version' not in params or
                                                       params['version'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version` when calling `get_metrics_policy_by_version`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version' in params:
            path_params['version'] = params['version']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/metricspolicy/history/{version}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerMetricsPolicyReadModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_metrics_policy_history(self, **kwargs):  # noqa: E501
        """Get the version history of metrics policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_metrics_policy_history(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :return: ResponseContainerHistoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_metrics_policy_history_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_metrics_policy_history_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_metrics_policy_history_with_http_info(self, **kwargs):  # noqa: E501
        """Get the version history of metrics policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_metrics_policy_history_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :return: ResponseContainerHistoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_metrics_policy_history" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/metricspolicy/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerHistoryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revert_metrics_policy_by_version(self, version, **kwargs):  # noqa: E501
        """Revert to a specific historical version of a metrics policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revert_metrics_policy_by_version(version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int version: (required)
        :return: ResponseContainerMetricsPolicyReadModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revert_metrics_policy_by_version_with_http_info(version, **kwargs)  # noqa: E501
        else:
            (data) = self.revert_metrics_policy_by_version_with_http_info(version, **kwargs)  # noqa: E501
            return data

    def revert_metrics_policy_by_version_with_http_info(self, version, **kwargs):  # noqa: E501
        """Revert to a specific historical version of a metrics policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revert_metrics_policy_by_version_with_http_info(version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int version: (required)
        :return: ResponseContainerMetricsPolicyReadModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revert_metrics_policy_by_version" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version' is set
        if self.api_client.client_side_validation and ('version' not in params or
                                                       params['version'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version` when calling `revert_metrics_policy_by_version`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version' in params:
            path_params['version'] = params['version']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/metricspolicy/revert/{version}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerMetricsPolicyReadModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_metrics_policy(self, **kwargs):  # noqa: E501
        """Update the metrics policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_metrics_policy(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MetricsPolicyWriteModel body: Example Body:  <pre>{ \"policyRules\": [{   \"name\": \"Policy rule1 name\",   \"description\": \"Policy rule1 description\",   \"prefixes\": [\"revenue.*\"],   \"tags\": [{\"key\":\"sensitive\",  \"value\":\"false\"},              {\"key\":\"source\",  \"value\":\"app1\"}],   \"tagsAnded\": \"true\",   \"accessType\": \"ALLOW\",   \"accounts\": [\"accountId1\", \"accountId2\"],   \"userGroups\": [\"userGroupId1\"],   \"roles\": [\"roleId\"] }, {   \"name\": \"Policy rule2 name\",   \"description\": \"Policy rule2 description\",   \"prefixes\": [\"revenue.*\"],   \"accessType\": \"BLOCK\",   \"accounts\": [\"accountId3\"],   \"userGroups\": [\"userGroupId1\"] }] }</pre>
        :return: ResponseContainerMetricsPolicyReadModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_metrics_policy_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.update_metrics_policy_with_http_info(**kwargs)  # noqa: E501
            return data

    def update_metrics_policy_with_http_info(self, **kwargs):  # noqa: E501
        """Update the metrics policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_metrics_policy_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MetricsPolicyWriteModel body: Example Body:  <pre>{ \"policyRules\": [{   \"name\": \"Policy rule1 name\",   \"description\": \"Policy rule1 description\",   \"prefixes\": [\"revenue.*\"],   \"tags\": [{\"key\":\"sensitive\",  \"value\":\"false\"},              {\"key\":\"source\",  \"value\":\"app1\"}],   \"tagsAnded\": \"true\",   \"accessType\": \"ALLOW\",   \"accounts\": [\"accountId1\", \"accountId2\"],   \"userGroups\": [\"userGroupId1\"],   \"roles\": [\"roleId\"] }, {   \"name\": \"Policy rule2 name\",   \"description\": \"Policy rule2 description\",   \"prefixes\": [\"revenue.*\"],   \"accessType\": \"BLOCK\",   \"accounts\": [\"accountId3\"],   \"userGroups\": [\"userGroupId1\"] }] }</pre>
        :return: ResponseContainerMetricsPolicyReadModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_metrics_policy" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/metricspolicy', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerMetricsPolicyReadModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class GCPConfiguration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'categories_to_fetch': 'list[str]',
        'custom_metric_prefix': 'list[str]',
        'disable_delta_counts': 'bool',
        'disable_histogram_to_metric_conversion': 'bool',
        'gcp_json_key': 'str',
        'metric_filter_regex': 'str',
        'project_id': 'str'
    }

    attribute_map = {
        'categories_to_fetch': 'categoriesToFetch',
        'custom_metric_prefix': 'customMetricPrefix',
        'disable_delta_counts': 'disableDeltaCounts',
        'disable_histogram_to_metric_conversion': 'disableHistogramToMetricConversion',
        'gcp_json_key': 'gcpJsonKey',
        'metric_filter_regex': 'metricFilterRegex',
        'project_id': 'projectId'
    }

    def __init__(self, categories_to_fetch=None, custom_metric_prefix=None, disable_delta_counts=None, disable_histogram_to_metric_conversion=None, gcp_json_key=None, metric_filter_regex=None, project_id=None, _configuration=None):  # noqa: E501
        """GCPConfiguration - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._categories_to_fetch = None
        self._custom_metric_prefix = None
        self._disable_delta_counts = None
        self._disable_histogram_to_metric_conversion = None
        self._gcp_json_key = None
        self._metric_filter_regex = None
        self._project_id = None
        self.discriminator = None

        if categories_to_fetch is not None:
            self.categories_to_fetch = categories_to_fetch
        if custom_metric_prefix is not None:
            self.custom_metric_prefix = custom_metric_prefix
        if disable_delta_counts is not None:
            self.disable_delta_counts = disable_delta_counts
        if disable_histogram_to_metric_conversion is not None:
            self.disable_histogram_to_metric_conversion = disable_histogram_to_metric_conversion
        self.gcp_json_key = gcp_json_key
        if metric_filter_regex is not None:
            self.metric_filter_regex = metric_filter_regex
        self.project_id = project_id

    @property
    def categories_to_fetch(self):
        """Gets the categories_to_fetch of this GCPConfiguration.  # noqa: E501

        A list of Google Cloud Platform (GCP) services (such as ComputeEngine, PubSub, etc) from which to pull metrics.  Allowable values are APPENGINE, BIGQUERY, BIGTABLE, CLOUDFUNCTIONS, CLOUDIOT, CLOUDSQL, CLOUDTASKS, COMPUTE, CONTAINER, DATAFLOW, DATAPROC, DATASTORE, FIREBASEDATABASE, FIREBASEHOSTING, FIRESTORE, INTERCONNECT, KUBERNETES, LOADBALANCING, LOGGING, ML, MONITORING, PUBSUB, REDIS, ROUTER, SERVICERUNTIME, SPANNER, STORAGE, TPU, VPN  # noqa: E501

        :return: The categories_to_fetch of this GCPConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._categories_to_fetch

    @categories_to_fetch.setter
    def categories_to_fetch(self, categories_to_fetch):
        """Sets the categories_to_fetch of this GCPConfiguration.

        A list of Google Cloud Platform (GCP) services (such as ComputeEngine, PubSub, etc) from which to pull metrics.  Allowable values are APPENGINE, BIGQUERY, BIGTABLE, CLOUDFUNCTIONS, CLOUDIOT, CLOUDSQL, CLOUDTASKS, COMPUTE, CONTAINER, DATAFLOW, DATAPROC, DATASTORE, FIREBASEDATABASE, FIREBASEHOSTING, FIRESTORE, INTERCONNECT, KUBERNETES, LOADBALANCING, LOGGING, ML, MONITORING, PUBSUB, REDIS, ROUTER, SERVICERUNTIME, SPANNER, STORAGE, TPU, VPN  # noqa: E501

        :param categories_to_fetch: The categories_to_fetch of this GCPConfiguration.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["APPENGINE", "BIGQUERY", "BIGTABLE", "CLOUDFUNCTIONS", "CLOUDIOT", "CLOUDSQL", "CLOUDTASKS", "COMPUTE", "CONTAINER", "DATAFLOW", "DATAPROC", "DATASTORE", "FIREBASEDATABASE", "FIREBASEHOSTING", "FIRESTORE", "INTERCONNECT", "KUBERNETES", "LOADBALANCING", "LOGGING", "ML", "MONITORING", "PUBSUB", "REDIS", "ROUTER", "SERVICERUNTIME", "SPANNER", "STORAGE", "TPU", "VPN"]  # noqa: E501
        if (self._configuration.client_side_validation and
                not set(categories_to_fetch).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `categories_to_fetch` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(categories_to_fetch) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._categories_to_fetch = categories_to_fetch

    @property
    def custom_metric_prefix(self):
        """Gets the custom_metric_prefix of this GCPConfiguration.  # noqa: E501

        List of custom metric prefix to fetch the data from  # noqa: E501

        :return: The custom_metric_prefix of this GCPConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._custom_metric_prefix

    @custom_metric_prefix.setter
    def custom_metric_prefix(self, custom_metric_prefix):
        """Sets the custom_metric_prefix of this GCPConfiguration.

        List of custom metric prefix to fetch the data from  # noqa: E501

        :param custom_metric_prefix: The custom_metric_prefix of this GCPConfiguration.  # noqa: E501
        :type: list[str]
        """

        self._custom_metric_prefix = custom_metric_prefix

    @property
    def disable_delta_counts(self):
        """Gets the disable_delta_counts of this GCPConfiguration.  # noqa: E501

        Whether to disable the ingestion of counts for GCP delta metrics. Ingestion is enabled by default.  # noqa: E501

        :return: The disable_delta_counts of this GCPConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._disable_delta_counts

    @disable_delta_counts.setter
    def disable_delta_counts(self, disable_delta_counts):
        """Sets the disable_delta_counts of this GCPConfiguration.

        Whether to disable the ingestion of counts for GCP delta metrics. Ingestion is enabled by default.  # noqa: E501

        :param disable_delta_counts: The disable_delta_counts of this GCPConfiguration.  # noqa: E501
        :type: bool
        """

        self._disable_delta_counts = disable_delta_counts

    @property
    def disable_histogram_to_metric_conversion(self):
        """Gets the disable_histogram_to_metric_conversion of this GCPConfiguration.  # noqa: E501

        Whether to disable the ingestion of bucket data for GCP distributions. Ingestion is enabled by default.  # noqa: E501

        :return: The disable_histogram_to_metric_conversion of this GCPConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._disable_histogram_to_metric_conversion

    @disable_histogram_to_metric_conversion.setter
    def disable_histogram_to_metric_conversion(self, disable_histogram_to_metric_conversion):
        """Sets the disable_histogram_to_metric_conversion of this GCPConfiguration.

        Whether to disable the ingestion of bucket data for GCP distributions. Ingestion is enabled by default.  # noqa: E501

        :param disable_histogram_to_metric_conversion: The disable_histogram_to_metric_conversion of this GCPConfiguration.  # noqa: E501
        :type: bool
        """

        self._disable_histogram_to_metric_conversion = disable_histogram_to_metric_conversion

    @property
    def gcp_json_key(self):
        """Gets the gcp_json_key of this GCPConfiguration.  # noqa: E501

        Private key for a Google Cloud Platform (GCP) service account within your project.  The account must at least be granted Monitoring Viewer permissions.  This key must be in the JSON format generated by GCP. Use '{\"project_id\": \"%s\"}' to retain the existing key when updating.  # noqa: E501

        :return: The gcp_json_key of this GCPConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._gcp_json_key

    @gcp_json_key.setter
    def gcp_json_key(self, gcp_json_key):
        """Sets the gcp_json_key of this GCPConfiguration.

        Private key for a Google Cloud Platform (GCP) service account within your project.  The account must at least be granted Monitoring Viewer permissions.  This key must be in the JSON format generated by GCP. Use '{\"project_id\": \"%s\"}' to retain the existing key when updating.  # noqa: E501

        :param gcp_json_key: The gcp_json_key of this GCPConfiguration.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and gcp_json_key is None:
            raise ValueError("Invalid value for `gcp_json_key`, must not be `None`")  # noqa: E501

        self._gcp_json_key = gcp_json_key

    @property
    def metric_filter_regex(self):
        """Gets the metric_filter_regex of this GCPConfiguration.  # noqa: E501

        A regular expression that a metric name must match (case-insensitively) in order to be ingested  # noqa: E501

        :return: The metric_filter_regex of this GCPConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._metric_filter_regex

    @metric_filter_regex.setter
    def metric_filter_regex(self, metric_filter_regex):
        """Sets the metric_filter_regex of this GCPConfiguration.

        A regular expression that a metric name must match (case-insensitively) in order to be ingested  # noqa: E501

        :param metric_filter_regex: The metric_filter_regex of this GCPConfiguration.  # noqa: E501
        :type: str
        """

        self._metric_filter_regex = metric_filter_regex

    @property
    def project_id(self):
        """Gets the project_id of this GCPConfiguration.  # noqa: E501

        The Google Cloud Platform (GCP) project id.  # noqa: E501

        :return: The project_id of this GCPConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this GCPConfiguration.

        The Google Cloud Platform (GCP) project id.  # noqa: E501

        :param project_id: The project_id of this GCPConfiguration.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GCPConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GCPConfiguration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GCPConfiguration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Package(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'annotations': 'list[Annotation]',
        'declared_annotations': 'list[Annotation]',
        'implementation_title': 'str',
        'implementation_vendor': 'str',
        'implementation_version': 'str',
        'name': 'str',
        'sealed': 'bool',
        'specification_title': 'str',
        'specification_vendor': 'str',
        'specification_version': 'str'
    }

    attribute_map = {
        'annotations': 'annotations',
        'declared_annotations': 'declaredAnnotations',
        'implementation_title': 'implementationTitle',
        'implementation_vendor': 'implementationVendor',
        'implementation_version': 'implementationVersion',
        'name': 'name',
        'sealed': 'sealed',
        'specification_title': 'specificationTitle',
        'specification_vendor': 'specificationVendor',
        'specification_version': 'specificationVersion'
    }

    def __init__(self, annotations=None, declared_annotations=None, implementation_title=None, implementation_vendor=None, implementation_version=None, name=None, sealed=None, specification_title=None, specification_vendor=None, specification_version=None, _configuration=None):  # noqa: E501
        """Package - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._annotations = None
        self._declared_annotations = None
        self._implementation_title = None
        self._implementation_vendor = None
        self._implementation_version = None
        self._name = None
        self._sealed = None
        self._specification_title = None
        self._specification_vendor = None
        self._specification_version = None
        self.discriminator = None

        if annotations is not None:
            self.annotations = annotations
        if declared_annotations is not None:
            self.declared_annotations = declared_annotations
        if implementation_title is not None:
            self.implementation_title = implementation_title
        if implementation_vendor is not None:
            self.implementation_vendor = implementation_vendor
        if implementation_version is not None:
            self.implementation_version = implementation_version
        if name is not None:
            self.name = name
        if sealed is not None:
            self.sealed = sealed
        if specification_title is not None:
            self.specification_title = specification_title
        if specification_vendor is not None:
            self.specification_vendor = specification_vendor
        if specification_version is not None:
            self.specification_version = specification_version

    @property
    def annotations(self):
        """Gets the annotations of this Package.  # noqa: E501


        :return: The annotations of this Package.  # noqa: E501
        :rtype: list[Annotation]
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this Package.


        :param annotations: The annotations of this Package.  # noqa: E501
        :type: list[Annotation]
        """

        self._annotations = annotations

    @property
    def declared_annotations(self):
        """Gets the declared_annotations of this Package.  # noqa: E501


        :return: The declared_annotations of this Package.  # noqa: E501
        :rtype: list[Annotation]
        """
        return self._declared_annotations

    @declared_annotations.setter
    def declared_annotations(self, declared_annotations):
        """Sets the declared_annotations of this Package.


        :param declared_annotations: The declared_annotations of this Package.  # noqa: E501
        :type: list[Annotation]
        """

        self._declared_annotations = declared_annotations

    @property
    def implementation_title(self):
        """Gets the implementation_title of this Package.  # noqa: E501


        :return: The implementation_title of this Package.  # noqa: E501
        :rtype: str
        """
        return self._implementation_title

    @implementation_title.setter
    def implementation_title(self, implementation_title):
        """Sets the implementation_title of this Package.


        :param implementation_title: The implementation_title of this Package.  # noqa: E501
        :type: str
        """

        self._implementation_title = implementation_title

    @property
    def implementation_vendor(self):
        """Gets the implementation_vendor of this Package.  # noqa: E501


        :return: The implementation_vendor of this Package.  # noqa: E501
        :rtype: str
        """
        return self._implementation_vendor

    @implementation_vendor.setter
    def implementation_vendor(self, implementation_vendor):
        """Sets the implementation_vendor of this Package.


        :param implementation_vendor: The implementation_vendor of this Package.  # noqa: E501
        :type: str
        """

        self._implementation_vendor = implementation_vendor

    @property
    def implementation_version(self):
        """Gets the implementation_version of this Package.  # noqa: E501


        :return: The implementation_version of this Package.  # noqa: E501
        :rtype: str
        """
        return self._implementation_version

    @implementation_version.setter
    def implementation_version(self, implementation_version):
        """Sets the implementation_version of this Package.


        :param implementation_version: The implementation_version of this Package.  # noqa: E501
        :type: str
        """

        self._implementation_version = implementation_version

    @property
    def name(self):
        """Gets the name of this Package.  # noqa: E501


        :return: The name of this Package.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Package.


        :param name: The name of this Package.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def sealed(self):
        """Gets the sealed of this Package.  # noqa: E501


        :return: The sealed of this Package.  # noqa: E501
        :rtype: bool
        """
        return self._sealed

    @sealed.setter
    def sealed(self, sealed):
        """Sets the sealed of this Package.


        :param sealed: The sealed of this Package.  # noqa: E501
        :type: bool
        """

        self._sealed = sealed

    @property
    def specification_title(self):
        """Gets the specification_title of this Package.  # noqa: E501


        :return: The specification_title of this Package.  # noqa: E501
        :rtype: str
        """
        return self._specification_title

    @specification_title.setter
    def specification_title(self, specification_title):
        """Sets the specification_title of this Package.


        :param specification_title: The specification_title of this Package.  # noqa: E501
        :type: str
        """

        self._specification_title = specification_title

    @property
    def specification_vendor(self):
        """Gets the specification_vendor of this Package.  # noqa: E501


        :return: The specification_vendor of this Package.  # noqa: E501
        :rtype: str
        """
        return self._specification_vendor

    @specification_vendor.setter
    def specification_vendor(self, specification_vendor):
        """Sets the specification_vendor of this Package.


        :param specification_vendor: The specification_vendor of this Package.  # noqa: E501
        :type: str
        """

        self._specification_vendor = specification_vendor

    @property
    def specification_version(self):
        """Gets the specification_version of this Package.  # noqa: E501


        :return: The specification_version of this Package.  # noqa: E501
        :rtype: str
        """
        return self._specification_version

    @specification_version.setter
    def specification_version(self, specification_version):
        """Sets the specification_version of this Package.


        :param specification_version: The specification_version of this Package.  # noqa: E501
        :type: str
        """

        self._specification_version = specification_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Package, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Package):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Package):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wavefront_api_client.api_client import ApiClient


class UsageApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_ingestion_policy(self, **kwargs):  # noqa: E501
        """Create a specific ingestion policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_ingestion_policy(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IngestionPolicy body: Example Body:  <pre>{   \"name\": \"Ingestion policy name\",   \"description\": \"Ingestion policy description\" }</pre>
        :return: ResponseContainerIngestionPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_ingestion_policy_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_ingestion_policy_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_ingestion_policy_with_http_info(self, **kwargs):  # noqa: E501
        """Create a specific ingestion policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_ingestion_policy_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IngestionPolicy body: Example Body:  <pre>{   \"name\": \"Ingestion policy name\",   \"description\": \"Ingestion policy description\" }</pre>
        :return: ResponseContainerIngestionPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_ingestion_policy" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usage/ingestionpolicy', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerIngestionPolicy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_ingestion_policy(self, id, **kwargs):  # noqa: E501
        """Delete a specific ingestion policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ingestion_policy(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerIngestionPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_ingestion_policy_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_ingestion_policy_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_ingestion_policy_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete a specific ingestion policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ingestion_policy_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerIngestionPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_ingestion_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_ingestion_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usage/ingestionpolicy/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerIngestionPolicy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_csv(self, start_time, **kwargs):  # noqa: E501
        """Export a CSV report  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_csv(start_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time: start time in epoch seconds (required)
        :param int end_time: end time in epoch seconds, null to use now
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.export_csv_with_http_info(start_time, **kwargs)  # noqa: E501
        else:
            (data) = self.export_csv_with_http_info(start_time, **kwargs)  # noqa: E501
            return data

    def export_csv_with_http_info(self, start_time, **kwargs):  # noqa: E501
        """Export a CSV report  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_csv_with_http_info(start_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time: start time in epoch seconds (required)
        :param int end_time: end time in epoch seconds, null to use now
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_csv" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'start_time' is set
        if self.api_client.client_side_validation and ('start_time' not in params or
                                                       params['start_time'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `start_time` when calling `export_csv`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usage/exportcsv', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_ingestion_policies(self, **kwargs):  # noqa: E501
        """Get all ingestion policies for a customer  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ingestion_policies(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :return: ResponseContainerPagedIngestionPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_ingestion_policies_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_ingestion_policies_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_ingestion_policies_with_http_info(self, **kwargs):  # noqa: E501
        """Get all ingestion policies for a customer  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ingestion_policies_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :return: ResponseContainerPagedIngestionPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_ingestion_policies" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usage/ingestionpolicy', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerPagedIngestionPolicy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ingestion_policy(self, id, **kwargs):  # noqa: E501
        """Get a specific ingestion policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ingestion_policy(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerIngestionPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ingestion_policy_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ingestion_policy_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_ingestion_policy_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get a specific ingestion policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ingestion_policy_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerIngestionPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ingestion_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_ingestion_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usage/ingestionpolicy/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerIngestionPolicy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_ingestion_policy(self, id, **kwargs):  # noqa: E501
        """Update a specific ingestion policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_ingestion_policy(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param IngestionPolicy body: Example Body:  <pre>{   \"name\": \"Ingestion policy name\",   \"description\": \"Ingestion policy description\" }</pre>
        :return: ResponseContainerIngestionPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_ingestion_policy_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_ingestion_policy_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def update_ingestion_policy_with_http_info(self, id, **kwargs):  # noqa: E501
        """Update a specific ingestion policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_ingestion_policy_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param IngestionPolicy body: Example Body:  <pre>{   \"name\": \"Ingestion policy name\",   \"description\": \"Ingestion policy description\" }</pre>
        :return: ResponseContainerIngestionPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_ingestion_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_ingestion_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/usage/ingestionpolicy/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerIngestionPolicy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class MaintenanceWindow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_epoch_millis': 'int',
        'creator_id': 'str',
        'customer_id': 'str',
        'end_time_in_seconds': 'int',
        'event_name': 'str',
        'host_tag_group_host_names_group_anded': 'bool',
        'id': 'str',
        'reason': 'str',
        'relevant_customer_tags': 'list[str]',
        'relevant_customer_tags_anded': 'bool',
        'relevant_host_names': 'list[str]',
        'relevant_host_tags': 'list[str]',
        'relevant_host_tags_anded': 'bool',
        'running_state': 'str',
        'sort_attr': 'int',
        'start_time_in_seconds': 'int',
        'title': 'str',
        'updated_epoch_millis': 'int',
        'updater_id': 'str'
    }

    attribute_map = {
        'created_epoch_millis': 'createdEpochMillis',
        'creator_id': 'creatorId',
        'customer_id': 'customerId',
        'end_time_in_seconds': 'endTimeInSeconds',
        'event_name': 'eventName',
        'host_tag_group_host_names_group_anded': 'hostTagGroupHostNamesGroupAnded',
        'id': 'id',
        'reason': 'reason',
        'relevant_customer_tags': 'relevantCustomerTags',
        'relevant_customer_tags_anded': 'relevantCustomerTagsAnded',
        'relevant_host_names': 'relevantHostNames',
        'relevant_host_tags': 'relevantHostTags',
        'relevant_host_tags_anded': 'relevantHostTagsAnded',
        'running_state': 'runningState',
        'sort_attr': 'sortAttr',
        'start_time_in_seconds': 'startTimeInSeconds',
        'title': 'title',
        'updated_epoch_millis': 'updatedEpochMillis',
        'updater_id': 'updaterId'
    }

    def __init__(self, created_epoch_millis=None, creator_id=None, customer_id=None, end_time_in_seconds=None, event_name=None, host_tag_group_host_names_group_anded=None, id=None, reason=None, relevant_customer_tags=None, relevant_customer_tags_anded=None, relevant_host_names=None, relevant_host_tags=None, relevant_host_tags_anded=None, running_state=None, sort_attr=None, start_time_in_seconds=None, title=None, updated_epoch_millis=None, updater_id=None, _configuration=None):  # noqa: E501
        """MaintenanceWindow - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._created_epoch_millis = None
        self._creator_id = None
        self._customer_id = None
        self._end_time_in_seconds = None
        self._event_name = None
        self._host_tag_group_host_names_group_anded = None
        self._id = None
        self._reason = None
        self._relevant_customer_tags = None
        self._relevant_customer_tags_anded = None
        self._relevant_host_names = None
        self._relevant_host_tags = None
        self._relevant_host_tags_anded = None
        self._running_state = None
        self._sort_attr = None
        self._start_time_in_seconds = None
        self._title = None
        self._updated_epoch_millis = None
        self._updater_id = None
        self.discriminator = None

        if created_epoch_millis is not None:
            self.created_epoch_millis = created_epoch_millis
        if creator_id is not None:
            self.creator_id = creator_id
        if customer_id is not None:
            self.customer_id = customer_id
        self.end_time_in_seconds = end_time_in_seconds
        if event_name is not None:
            self.event_name = event_name
        if host_tag_group_host_names_group_anded is not None:
            self.host_tag_group_host_names_group_anded = host_tag_group_host_names_group_anded
        if id is not None:
            self.id = id
        self.reason = reason
        self.relevant_customer_tags = relevant_customer_tags
        if relevant_customer_tags_anded is not None:
            self.relevant_customer_tags_anded = relevant_customer_tags_anded
        if relevant_host_names is not None:
            self.relevant_host_names = relevant_host_names
        if relevant_host_tags is not None:
            self.relevant_host_tags = relevant_host_tags
        if relevant_host_tags_anded is not None:
            self.relevant_host_tags_anded = relevant_host_tags_anded
        if running_state is not None:
            self.running_state = running_state
        if sort_attr is not None:
            self.sort_attr = sort_attr
        self.start_time_in_seconds = start_time_in_seconds
        self.title = title
        if updated_epoch_millis is not None:
            self.updated_epoch_millis = updated_epoch_millis
        if updater_id is not None:
            self.updater_id = updater_id

    @property
    def created_epoch_millis(self):
        """Gets the created_epoch_millis of this MaintenanceWindow.  # noqa: E501


        :return: The created_epoch_millis of this MaintenanceWindow.  # noqa: E501
        :rtype: int
        """
        return self._created_epoch_millis

    @created_epoch_millis.setter
    def created_epoch_millis(self, created_epoch_millis):
        """Sets the created_epoch_millis of this MaintenanceWindow.


        :param created_epoch_millis: The created_epoch_millis of this MaintenanceWindow.  # noqa: E501
        :type: int
        """

        self._created_epoch_millis = created_epoch_millis

    @property
    def creator_id(self):
        """Gets the creator_id of this MaintenanceWindow.  # noqa: E501


        :return: The creator_id of this MaintenanceWindow.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this MaintenanceWindow.


        :param creator_id: The creator_id of this MaintenanceWindow.  # noqa: E501
        :type: str
        """

        self._creator_id = creator_id

    @property
    def customer_id(self):
        """Gets the customer_id of this MaintenanceWindow.  # noqa: E501


        :return: The customer_id of this MaintenanceWindow.  # noqa: E501
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this MaintenanceWindow.


        :param customer_id: The customer_id of this MaintenanceWindow.  # noqa: E501
        :type: str
        """

        self._customer_id = customer_id

    @property
    def end_time_in_seconds(self):
        """Gets the end_time_in_seconds of this MaintenanceWindow.  # noqa: E501

        The time in epoch seconds when this maintenance window will end  # noqa: E501

        :return: The end_time_in_seconds of this MaintenanceWindow.  # noqa: E501
        :rtype: int
        """
        return self._end_time_in_seconds

    @end_time_in_seconds.setter
    def end_time_in_seconds(self, end_time_in_seconds):
        """Sets the end_time_in_seconds of this MaintenanceWindow.

        The time in epoch seconds when this maintenance window will end  # noqa: E501

        :param end_time_in_seconds: The end_time_in_seconds of this MaintenanceWindow.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and end_time_in_seconds is None:
            raise ValueError("Invalid value for `end_time_in_seconds`, must not be `None`")  # noqa: E501

        self._end_time_in_seconds = end_time_in_seconds

    @property
    def event_name(self):
        """Gets the event_name of this MaintenanceWindow.  # noqa: E501

        The name of an event associated with the creation/update of this maintenance window  # noqa: E501

        :return: The event_name of this MaintenanceWindow.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this MaintenanceWindow.

        The name of an event associated with the creation/update of this maintenance window  # noqa: E501

        :param event_name: The event_name of this MaintenanceWindow.  # noqa: E501
        :type: str
        """

        self._event_name = event_name

    @property
    def host_tag_group_host_names_group_anded(self):
        """Gets the host_tag_group_host_names_group_anded of this MaintenanceWindow.  # noqa: E501

        If true, a source/host must be in 'relevantHostNames' and have tags matching the specification formed by 'relevantHostTags' and 'relevantHostTagsAnded' in order for this maintenance window to apply. If false, a source/host must either be in 'relevantHostNames' or match 'relevantHostTags' and 'relevantHostTagsAnded'. Default: false  # noqa: E501

        :return: The host_tag_group_host_names_group_anded of this MaintenanceWindow.  # noqa: E501
        :rtype: bool
        """
        return self._host_tag_group_host_names_group_anded

    @host_tag_group_host_names_group_anded.setter
    def host_tag_group_host_names_group_anded(self, host_tag_group_host_names_group_anded):
        """Sets the host_tag_group_host_names_group_anded of this MaintenanceWindow.

        If true, a source/host must be in 'relevantHostNames' and have tags matching the specification formed by 'relevantHostTags' and 'relevantHostTagsAnded' in order for this maintenance window to apply. If false, a source/host must either be in 'relevantHostNames' or match 'relevantHostTags' and 'relevantHostTagsAnded'. Default: false  # noqa: E501

        :param host_tag_group_host_names_group_anded: The host_tag_group_host_names_group_anded of this MaintenanceWindow.  # noqa: E501
        :type: bool
        """

        self._host_tag_group_host_names_group_anded = host_tag_group_host_names_group_anded

    @property
    def id(self):
        """Gets the id of this MaintenanceWindow.  # noqa: E501


        :return: The id of this MaintenanceWindow.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MaintenanceWindow.


        :param id: The id of this MaintenanceWindow.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def reason(self):
        """Gets the reason of this MaintenanceWindow.  # noqa: E501

        The purpose of this maintenance window  # noqa: E501

        :return: The reason of this MaintenanceWindow.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this MaintenanceWindow.

        The purpose of this maintenance window  # noqa: E501

        :param reason: The reason of this MaintenanceWindow.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and reason is None:
            raise ValueError("Invalid value for `reason`, must not be `None`")  # noqa: E501

        self._reason = reason

    @property
    def relevant_customer_tags(self):
        """Gets the relevant_customer_tags of this MaintenanceWindow.  # noqa: E501

        List of alert tags whose matching alerts will be put into maintenance because of this maintenance window  # noqa: E501

        :return: The relevant_customer_tags of this MaintenanceWindow.  # noqa: E501
        :rtype: list[str]
        """
        return self._relevant_customer_tags

    @relevant_customer_tags.setter
    def relevant_customer_tags(self, relevant_customer_tags):
        """Sets the relevant_customer_tags of this MaintenanceWindow.

        List of alert tags whose matching alerts will be put into maintenance because of this maintenance window  # noqa: E501

        :param relevant_customer_tags: The relevant_customer_tags of this MaintenanceWindow.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and relevant_customer_tags is None:
            raise ValueError("Invalid value for `relevant_customer_tags`, must not be `None`")  # noqa: E501

        self._relevant_customer_tags = relevant_customer_tags

    @property
    def relevant_customer_tags_anded(self):
        """Gets the relevant_customer_tags_anded of this MaintenanceWindow.  # noqa: E501

        Whether to AND customer tags listed in relevantCustomerTags. If true, a customer must contain all tags in order for the maintenance window to apply.  If false, the tags are OR'ed, and a customer must contain one of the tags. Default: false  # noqa: E501

        :return: The relevant_customer_tags_anded of this MaintenanceWindow.  # noqa: E501
        :rtype: bool
        """
        return self._relevant_customer_tags_anded

    @relevant_customer_tags_anded.setter
    def relevant_customer_tags_anded(self, relevant_customer_tags_anded):
        """Sets the relevant_customer_tags_anded of this MaintenanceWindow.

        Whether to AND customer tags listed in relevantCustomerTags. If true, a customer must contain all tags in order for the maintenance window to apply.  If false, the tags are OR'ed, and a customer must contain one of the tags. Default: false  # noqa: E501

        :param relevant_customer_tags_anded: The relevant_customer_tags_anded of this MaintenanceWindow.  # noqa: E501
        :type: bool
        """

        self._relevant_customer_tags_anded = relevant_customer_tags_anded

    @property
    def relevant_host_names(self):
        """Gets the relevant_host_names of this MaintenanceWindow.  # noqa: E501

        List of source/host names that will be put into maintenance because of this maintenance window  # noqa: E501

        :return: The relevant_host_names of this MaintenanceWindow.  # noqa: E501
        :rtype: list[str]
        """
        return self._relevant_host_names

    @relevant_host_names.setter
    def relevant_host_names(self, relevant_host_names):
        """Sets the relevant_host_names of this MaintenanceWindow.

        List of source/host names that will be put into maintenance because of this maintenance window  # noqa: E501

        :param relevant_host_names: The relevant_host_names of this MaintenanceWindow.  # noqa: E501
        :type: list[str]
        """

        self._relevant_host_names = relevant_host_names

    @property
    def relevant_host_tags(self):
        """Gets the relevant_host_tags of this MaintenanceWindow.  # noqa: E501

        List of source/host tags whose matching sources/hosts will be put into maintenance because of this maintenance window  # noqa: E501

        :return: The relevant_host_tags of this MaintenanceWindow.  # noqa: E501
        :rtype: list[str]
        """
        return self._relevant_host_tags

    @relevant_host_tags.setter
    def relevant_host_tags(self, relevant_host_tags):
        """Sets the relevant_host_tags of this MaintenanceWindow.

        List of source/host tags whose matching sources/hosts will be put into maintenance because of this maintenance window  # noqa: E501

        :param relevant_host_tags: The relevant_host_tags of this MaintenanceWindow.  # noqa: E501
        :type: list[str]
        """

        self._relevant_host_tags = relevant_host_tags

    @property
    def relevant_host_tags_anded(self):
        """Gets the relevant_host_tags_anded of this MaintenanceWindow.  # noqa: E501

        Whether to AND source/host tags listed in relevantHostTags. If true, a source/host must contain all tags in order for the maintenance window to apply.  If false, the tags are OR'ed, and a source/host must contain one of the tags. Default: false  # noqa: E501

        :return: The relevant_host_tags_anded of this MaintenanceWindow.  # noqa: E501
        :rtype: bool
        """
        return self._relevant_host_tags_anded

    @relevant_host_tags_anded.setter
    def relevant_host_tags_anded(self, relevant_host_tags_anded):
        """Sets the relevant_host_tags_anded of this MaintenanceWindow.

        Whether to AND source/host tags listed in relevantHostTags. If true, a source/host must contain all tags in order for the maintenance window to apply.  If false, the tags are OR'ed, and a source/host must contain one of the tags. Default: false  # noqa: E501

        :param relevant_host_tags_anded: The relevant_host_tags_anded of this MaintenanceWindow.  # noqa: E501
        :type: bool
        """

        self._relevant_host_tags_anded = relevant_host_tags_anded

    @property
    def running_state(self):
        """Gets the running_state of this MaintenanceWindow.  # noqa: E501


        :return: The running_state of this MaintenanceWindow.  # noqa: E501
        :rtype: str
        """
        return self._running_state

    @running_state.setter
    def running_state(self, running_state):
        """Sets the running_state of this MaintenanceWindow.


        :param running_state: The running_state of this MaintenanceWindow.  # noqa: E501
        :type: str
        """
        allowed_values = ["ONGOING", "PENDING", "ENDED"]  # noqa: E501
        if (self._configuration.client_side_validation and
                running_state not in allowed_values):
            raise ValueError(
                "Invalid value for `running_state` ({0}), must be one of {1}"  # noqa: E501
                .format(running_state, allowed_values)
            )

        self._running_state = running_state

    @property
    def sort_attr(self):
        """Gets the sort_attr of this MaintenanceWindow.  # noqa: E501

        Numeric value used in default sorting  # noqa: E501

        :return: The sort_attr of this MaintenanceWindow.  # noqa: E501
        :rtype: int
        """
        return self._sort_attr

    @sort_attr.setter
    def sort_attr(self, sort_attr):
        """Sets the sort_attr of this MaintenanceWindow.

        Numeric value used in default sorting  # noqa: E501

        :param sort_attr: The sort_attr of this MaintenanceWindow.  # noqa: E501
        :type: int
        """

        self._sort_attr = sort_attr

    @property
    def start_time_in_seconds(self):
        """Gets the start_time_in_seconds of this MaintenanceWindow.  # noqa: E501

        The time in epoch seconds when this maintenance window will start  # noqa: E501

        :return: The start_time_in_seconds of this MaintenanceWindow.  # noqa: E501
        :rtype: int
        """
        return self._start_time_in_seconds

    @start_time_in_seconds.setter
    def start_time_in_seconds(self, start_time_in_seconds):
        """Sets the start_time_in_seconds of this MaintenanceWindow.

        The time in epoch seconds when this maintenance window will start  # noqa: E501

        :param start_time_in_seconds: The start_time_in_seconds of this MaintenanceWindow.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and start_time_in_seconds is None:
            raise ValueError("Invalid value for `start_time_in_seconds`, must not be `None`")  # noqa: E501

        self._start_time_in_seconds = start_time_in_seconds

    @property
    def title(self):
        """Gets the title of this MaintenanceWindow.  # noqa: E501

        Title of this maintenance window  # noqa: E501

        :return: The title of this MaintenanceWindow.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this MaintenanceWindow.

        Title of this maintenance window  # noqa: E501

        :param title: The title of this MaintenanceWindow.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def updated_epoch_millis(self):
        """Gets the updated_epoch_millis of this MaintenanceWindow.  # noqa: E501


        :return: The updated_epoch_millis of this MaintenanceWindow.  # noqa: E501
        :rtype: int
        """
        return self._updated_epoch_millis

    @updated_epoch_millis.setter
    def updated_epoch_millis(self, updated_epoch_millis):
        """Sets the updated_epoch_millis of this MaintenanceWindow.


        :param updated_epoch_millis: The updated_epoch_millis of this MaintenanceWindow.  # noqa: E501
        :type: int
        """

        self._updated_epoch_millis = updated_epoch_millis

    @property
    def updater_id(self):
        """Gets the updater_id of this MaintenanceWindow.  # noqa: E501


        :return: The updater_id of this MaintenanceWindow.  # noqa: E501
        :rtype: str
        """
        return self._updater_id

    @updater_id.setter
    def updater_id(self, updater_id):
        """Sets the updater_id of this MaintenanceWindow.


        :param updater_id: The updater_id of this MaintenanceWindow.  # noqa: E501
        :type: str
        """

        self._updater_id = updater_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MaintenanceWindow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MaintenanceWindow):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MaintenanceWindow):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class ValidatedUsersDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'invalid_identifiers': 'list[str]',
        'valid_users': 'list[UserDTO]'
    }

    attribute_map = {
        'invalid_identifiers': 'invalidIdentifiers',
        'valid_users': 'validUsers'
    }

    def __init__(self, invalid_identifiers=None, valid_users=None, _configuration=None):  # noqa: E501
        """ValidatedUsersDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._invalid_identifiers = None
        self._valid_users = None
        self.discriminator = None

        if invalid_identifiers is not None:
            self.invalid_identifiers = invalid_identifiers
        if valid_users is not None:
            self.valid_users = valid_users

    @property
    def invalid_identifiers(self):
        """Gets the invalid_identifiers of this ValidatedUsersDTO.  # noqa: E501


        :return: The invalid_identifiers of this ValidatedUsersDTO.  # noqa: E501
        :rtype: list[str]
        """
        return self._invalid_identifiers

    @invalid_identifiers.setter
    def invalid_identifiers(self, invalid_identifiers):
        """Sets the invalid_identifiers of this ValidatedUsersDTO.


        :param invalid_identifiers: The invalid_identifiers of this ValidatedUsersDTO.  # noqa: E501
        :type: list[str]
        """

        self._invalid_identifiers = invalid_identifiers

    @property
    def valid_users(self):
        """Gets the valid_users of this ValidatedUsersDTO.  # noqa: E501


        :return: The valid_users of this ValidatedUsersDTO.  # noqa: E501
        :rtype: list[UserDTO]
        """
        return self._valid_users

    @valid_users.setter
    def valid_users(self, valid_users):
        """Sets the valid_users of this ValidatedUsersDTO.


        :param valid_users: The valid_users of this ValidatedUsersDTO.  # noqa: E501
        :type: list[UserDTO]
        """

        self._valid_users = valid_users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ValidatedUsersDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ValidatedUsersDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ValidatedUsersDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class ClassLoader(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'defined_packages': 'list[Package]',
        'name': 'str',
        'parent': 'ClassLoader',
        'registered_as_parallel_capable': 'bool',
        'unnamed_module': 'Module'
    }

    attribute_map = {
        'defined_packages': 'definedPackages',
        'name': 'name',
        'parent': 'parent',
        'registered_as_parallel_capable': 'registeredAsParallelCapable',
        'unnamed_module': 'unnamedModule'
    }

    def __init__(self, defined_packages=None, name=None, parent=None, registered_as_parallel_capable=None, unnamed_module=None, _configuration=None):  # noqa: E501
        """ClassLoader - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._defined_packages = None
        self._name = None
        self._parent = None
        self._registered_as_parallel_capable = None
        self._unnamed_module = None
        self.discriminator = None

        if defined_packages is not None:
            self.defined_packages = defined_packages
        if name is not None:
            self.name = name
        if parent is not None:
            self.parent = parent
        if registered_as_parallel_capable is not None:
            self.registered_as_parallel_capable = registered_as_parallel_capable
        if unnamed_module is not None:
            self.unnamed_module = unnamed_module

    @property
    def defined_packages(self):
        """Gets the defined_packages of this ClassLoader.  # noqa: E501


        :return: The defined_packages of this ClassLoader.  # noqa: E501
        :rtype: list[Package]
        """
        return self._defined_packages

    @defined_packages.setter
    def defined_packages(self, defined_packages):
        """Sets the defined_packages of this ClassLoader.


        :param defined_packages: The defined_packages of this ClassLoader.  # noqa: E501
        :type: list[Package]
        """

        self._defined_packages = defined_packages

    @property
    def name(self):
        """Gets the name of this ClassLoader.  # noqa: E501


        :return: The name of this ClassLoader.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ClassLoader.


        :param name: The name of this ClassLoader.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def parent(self):
        """Gets the parent of this ClassLoader.  # noqa: E501


        :return: The parent of this ClassLoader.  # noqa: E501
        :rtype: ClassLoader
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this ClassLoader.


        :param parent: The parent of this ClassLoader.  # noqa: E501
        :type: ClassLoader
        """

        self._parent = parent

    @property
    def registered_as_parallel_capable(self):
        """Gets the registered_as_parallel_capable of this ClassLoader.  # noqa: E501


        :return: The registered_as_parallel_capable of this ClassLoader.  # noqa: E501
        :rtype: bool
        """
        return self._registered_as_parallel_capable

    @registered_as_parallel_capable.setter
    def registered_as_parallel_capable(self, registered_as_parallel_capable):
        """Sets the registered_as_parallel_capable of this ClassLoader.


        :param registered_as_parallel_capable: The registered_as_parallel_capable of this ClassLoader.  # noqa: E501
        :type: bool
        """

        self._registered_as_parallel_capable = registered_as_parallel_capable

    @property
    def unnamed_module(self):
        """Gets the unnamed_module of this ClassLoader.  # noqa: E501


        :return: The unnamed_module of this ClassLoader.  # noqa: E501
        :rtype: Module
        """
        return self._unnamed_module

    @unnamed_module.setter
    def unnamed_module(self, unnamed_module):
        """Sets the unnamed_module of this ClassLoader.


        :param unnamed_module: The unnamed_module of this ClassLoader.  # noqa: E501
        :type: Module
        """

        self._unnamed_module = unnamed_module

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClassLoader, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClassLoader):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ClassLoader):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class PagedMonitoredServiceDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cursor': 'str',
        'items': 'list[MonitoredServiceDTO]',
        'limit': 'int',
        'more_items': 'bool',
        'offset': 'int',
        'sort': 'Sorting',
        'total_items': 'int'
    }

    attribute_map = {
        'cursor': 'cursor',
        'items': 'items',
        'limit': 'limit',
        'more_items': 'moreItems',
        'offset': 'offset',
        'sort': 'sort',
        'total_items': 'totalItems'
    }

    def __init__(self, cursor=None, items=None, limit=None, more_items=None, offset=None, sort=None, total_items=None, _configuration=None):  # noqa: E501
        """PagedMonitoredServiceDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cursor = None
        self._items = None
        self._limit = None
        self._more_items = None
        self._offset = None
        self._sort = None
        self._total_items = None
        self.discriminator = None

        if cursor is not None:
            self.cursor = cursor
        if items is not None:
            self.items = items
        if limit is not None:
            self.limit = limit
        if more_items is not None:
            self.more_items = more_items
        if offset is not None:
            self.offset = offset
        if sort is not None:
            self.sort = sort
        if total_items is not None:
            self.total_items = total_items

    @property
    def cursor(self):
        """Gets the cursor of this PagedMonitoredServiceDTO.  # noqa: E501

        The id at which the current (limited) search can be continued to obtain more matching items  # noqa: E501

        :return: The cursor of this PagedMonitoredServiceDTO.  # noqa: E501
        :rtype: str
        """
        return self._cursor

    @cursor.setter
    def cursor(self, cursor):
        """Sets the cursor of this PagedMonitoredServiceDTO.

        The id at which the current (limited) search can be continued to obtain more matching items  # noqa: E501

        :param cursor: The cursor of this PagedMonitoredServiceDTO.  # noqa: E501
        :type: str
        """

        self._cursor = cursor

    @property
    def items(self):
        """Gets the items of this PagedMonitoredServiceDTO.  # noqa: E501

        List of requested items  # noqa: E501

        :return: The items of this PagedMonitoredServiceDTO.  # noqa: E501
        :rtype: list[MonitoredServiceDTO]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this PagedMonitoredServiceDTO.

        List of requested items  # noqa: E501

        :param items: The items of this PagedMonitoredServiceDTO.  # noqa: E501
        :type: list[MonitoredServiceDTO]
        """

        self._items = items

    @property
    def limit(self):
        """Gets the limit of this PagedMonitoredServiceDTO.  # noqa: E501


        :return: The limit of this PagedMonitoredServiceDTO.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this PagedMonitoredServiceDTO.


        :param limit: The limit of this PagedMonitoredServiceDTO.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def more_items(self):
        """Gets the more_items of this PagedMonitoredServiceDTO.  # noqa: E501

        Whether more items are available for return by increment offset or cursor  # noqa: E501

        :return: The more_items of this PagedMonitoredServiceDTO.  # noqa: E501
        :rtype: bool
        """
        return self._more_items

    @more_items.setter
    def more_items(self, more_items):
        """Sets the more_items of this PagedMonitoredServiceDTO.

        Whether more items are available for return by increment offset or cursor  # noqa: E501

        :param more_items: The more_items of this PagedMonitoredServiceDTO.  # noqa: E501
        :type: bool
        """

        self._more_items = more_items

    @property
    def offset(self):
        """Gets the offset of this PagedMonitoredServiceDTO.  # noqa: E501


        :return: The offset of this PagedMonitoredServiceDTO.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this PagedMonitoredServiceDTO.


        :param offset: The offset of this PagedMonitoredServiceDTO.  # noqa: E501
        :type: int
        """

        self._offset = offset

    @property
    def sort(self):
        """Gets the sort of this PagedMonitoredServiceDTO.  # noqa: E501


        :return: The sort of this PagedMonitoredServiceDTO.  # noqa: E501
        :rtype: Sorting
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this PagedMonitoredServiceDTO.


        :param sort: The sort of this PagedMonitoredServiceDTO.  # noqa: E501
        :type: Sorting
        """

        self._sort = sort

    @property
    def total_items(self):
        """Gets the total_items of this PagedMonitoredServiceDTO.  # noqa: E501

        An estimate (lower-bound) of the total number of items available for return.  May not be a tight estimate for facet queries  # noqa: E501

        :return: The total_items of this PagedMonitoredServiceDTO.  # noqa: E501
        :rtype: int
        """
        return self._total_items

    @total_items.setter
    def total_items(self, total_items):
        """Sets the total_items of this PagedMonitoredServiceDTO.

        An estimate (lower-bound) of the total number of items available for return.  May not be a tight estimate for facet queries  # noqa: E501

        :param total_items: The total_items of this PagedMonitoredServiceDTO.  # noqa: E501
        :type: int
        """

        self._total_items = total_items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PagedMonitoredServiceDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PagedMonitoredServiceDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PagedMonitoredServiceDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class RelatedData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alert_description': 'str',
        'anomaly_chart_link': 'str',
        'common_dimensions': 'list[str]',
        'common_metrics': 'list[str]',
        'common_sources': 'list[str]',
        'enhanced_score': 'float',
        'related_id': 'str',
        'summary': 'str'
    }

    attribute_map = {
        'alert_description': 'alertDescription',
        'anomaly_chart_link': 'anomalyChartLink',
        'common_dimensions': 'commonDimensions',
        'common_metrics': 'commonMetrics',
        'common_sources': 'commonSources',
        'enhanced_score': 'enhancedScore',
        'related_id': 'relatedId',
        'summary': 'summary'
    }

    def __init__(self, alert_description=None, anomaly_chart_link=None, common_dimensions=None, common_metrics=None, common_sources=None, enhanced_score=None, related_id=None, summary=None, _configuration=None):  # noqa: E501
        """RelatedData - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._alert_description = None
        self._anomaly_chart_link = None
        self._common_dimensions = None
        self._common_metrics = None
        self._common_sources = None
        self._enhanced_score = None
        self._related_id = None
        self._summary = None
        self.discriminator = None

        if alert_description is not None:
            self.alert_description = alert_description
        if anomaly_chart_link is not None:
            self.anomaly_chart_link = anomaly_chart_link
        if common_dimensions is not None:
            self.common_dimensions = common_dimensions
        if common_metrics is not None:
            self.common_metrics = common_metrics
        if common_sources is not None:
            self.common_sources = common_sources
        if enhanced_score is not None:
            self.enhanced_score = enhanced_score
        if related_id is not None:
            self.related_id = related_id
        if summary is not None:
            self.summary = summary

    @property
    def alert_description(self):
        """Gets the alert_description of this RelatedData.  # noqa: E501

        If this event is generated by an alert, the description of that alert.  # noqa: E501

        :return: The alert_description of this RelatedData.  # noqa: E501
        :rtype: str
        """
        return self._alert_description

    @alert_description.setter
    def alert_description(self, alert_description):
        """Sets the alert_description of this RelatedData.

        If this event is generated by an alert, the description of that alert.  # noqa: E501

        :param alert_description: The alert_description of this RelatedData.  # noqa: E501
        :type: str
        """

        self._alert_description = alert_description

    @property
    def anomaly_chart_link(self):
        """Gets the anomaly_chart_link of this RelatedData.  # noqa: E501

        Chart Link of the anomaly to which this event is related  # noqa: E501

        :return: The anomaly_chart_link of this RelatedData.  # noqa: E501
        :rtype: str
        """
        return self._anomaly_chart_link

    @anomaly_chart_link.setter
    def anomaly_chart_link(self, anomaly_chart_link):
        """Sets the anomaly_chart_link of this RelatedData.

        Chart Link of the anomaly to which this event is related  # noqa: E501

        :param anomaly_chart_link: The anomaly_chart_link of this RelatedData.  # noqa: E501
        :type: str
        """

        self._anomaly_chart_link = anomaly_chart_link

    @property
    def common_dimensions(self):
        """Gets the common_dimensions of this RelatedData.  # noqa: E501

        Set of common dimensions between the 2 events, presented in key=value format  # noqa: E501

        :return: The common_dimensions of this RelatedData.  # noqa: E501
        :rtype: list[str]
        """
        return self._common_dimensions

    @common_dimensions.setter
    def common_dimensions(self, common_dimensions):
        """Sets the common_dimensions of this RelatedData.

        Set of common dimensions between the 2 events, presented in key=value format  # noqa: E501

        :param common_dimensions: The common_dimensions of this RelatedData.  # noqa: E501
        :type: list[str]
        """

        self._common_dimensions = common_dimensions

    @property
    def common_metrics(self):
        """Gets the common_metrics of this RelatedData.  # noqa: E501

        Set of common metrics/labels between the 2 events or anomalies  # noqa: E501

        :return: The common_metrics of this RelatedData.  # noqa: E501
        :rtype: list[str]
        """
        return self._common_metrics

    @common_metrics.setter
    def common_metrics(self, common_metrics):
        """Sets the common_metrics of this RelatedData.

        Set of common metrics/labels between the 2 events or anomalies  # noqa: E501

        :param common_metrics: The common_metrics of this RelatedData.  # noqa: E501
        :type: list[str]
        """

        self._common_metrics = common_metrics

    @property
    def common_sources(self):
        """Gets the common_sources of this RelatedData.  # noqa: E501

        Set of common sources between the 2 events or anomalies  # noqa: E501

        :return: The common_sources of this RelatedData.  # noqa: E501
        :rtype: list[str]
        """
        return self._common_sources

    @common_sources.setter
    def common_sources(self, common_sources):
        """Sets the common_sources of this RelatedData.

        Set of common sources between the 2 events or anomalies  # noqa: E501

        :param common_sources: The common_sources of this RelatedData.  # noqa: E501
        :type: list[str]
        """

        self._common_sources = common_sources

    @property
    def enhanced_score(self):
        """Gets the enhanced_score of this RelatedData.  # noqa: E501

        Enhanced score to sort related events and anomalies  # noqa: E501

        :return: The enhanced_score of this RelatedData.  # noqa: E501
        :rtype: float
        """
        return self._enhanced_score

    @enhanced_score.setter
    def enhanced_score(self, enhanced_score):
        """Sets the enhanced_score of this RelatedData.

        Enhanced score to sort related events and anomalies  # noqa: E501

        :param enhanced_score: The enhanced_score of this RelatedData.  # noqa: E501
        :type: float
        """

        self._enhanced_score = enhanced_score

    @property
    def related_id(self):
        """Gets the related_id of this RelatedData.  # noqa: E501

        ID of the event to which this event is related  # noqa: E501

        :return: The related_id of this RelatedData.  # noqa: E501
        :rtype: str
        """
        return self._related_id

    @related_id.setter
    def related_id(self, related_id):
        """Sets the related_id of this RelatedData.

        ID of the event to which this event is related  # noqa: E501

        :param related_id: The related_id of this RelatedData.  # noqa: E501
        :type: str
        """

        self._related_id = related_id

    @property
    def summary(self):
        """Gets the summary of this RelatedData.  # noqa: E501

        Text summary of why the two events are related  # noqa: E501

        :return: The summary of this RelatedData.  # noqa: E501
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this RelatedData.

        Text summary of why the two events are related  # noqa: E501

        :param summary: The summary of this RelatedData.  # noqa: E501
        :type: str
        """

        self._summary = summary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RelatedData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RelatedData):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RelatedData):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.proxy_api import ProxyApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestProxyApi(unittest.TestCase):
    """ProxyApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.proxy_api.ProxyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_proxy(self):
        """Test case for delete_proxy

        Delete a specific proxy  # noqa: E501
        """
        pass

    def test_get_all_proxy(self):
        """Test case for get_all_proxy

        Get all proxies for a customer  # noqa: E501
        """
        pass

    def test_get_proxy(self):
        """Test case for get_proxy

        Get a specific proxy  # noqa: E501
        """
        pass

    def test_undelete_proxy(self):
        """Test case for undelete_proxy

        Undelete a specific proxy  # noqa: E501
        """
        pass

    def test_update_proxy(self):
        """Test case for update_proxy

        Update the name of a specific proxy  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
